#!/bin/bash

RUNDIR=$(pwd)

# Remove eventual leftovers
rm -rf AutoRPE/   ../Remote/ProcessedOutputs/

#download last AutoRPE version
#git clone http://earth.bsc.es/gitlab/otinto/AutoRPE.git
git clone http://earth.bsc.es/gitlab/otinto/AutoRPE.git --branch dwarf-lonlev-0.91_0


DWARF=/home/Earth/sparonuz/Documents/Codes/dwarf-lonlev-0.91_0
DWARF_SRC=${DWARF}/src
DWARF_NAMELIST=${DWARF}/escape-acraneb2-input-output/nam_radia_dwarf.nam

if [[ ! -d ${DWARF_SRC} ]]
then
  echo -e "the folder" ${DWARF_SRC} " does not exist\nAbort..."
  exit 1
fi

AUTORP_HOME=${RUNDIR}/AutoRPE
AutoRPE_Input=${AUTORP_HOME}/ModelSources/Input/
AutoRPE_Output=${AUTORP_HOME}/ModelSources/Output/
OLD_NAMELIST=${AUTORP_HOME}/ParameterNamelists/Original/
NEW_NAMELIST=${AUTORP_HOME}/ParameterNamelists/Modified/

# Folder on HPC in which the remote implementation will run
REMOTE_DIR=/home/bsc32/bsc32402/local/recipe_4_dwarf-lonlev-0.91_0

# Copy just sources
cp ${DWARF_SRC}/*.f90 ${AutoRPE_Input}

# Copy namelist original namelist
cp ${DWARF_NAMELIST} ${OLD_NAMELIST}

# Precompile files when needed
for file in ${DWARF_SRC}/*.F90
do
 dest_file=${file//${DWARF_SRC}}
 cpp -P -fopenmp  ${file} > ${AutoRPE_Input}/${dest_file//F90}f90
done

# Remove legacy files
rm ${AutoRPE_Input}/*_legacy*

# Ignore opmpi files and timings, which contains no calculation at all
echo -e  \
 'dmi_omp.F90' \
 '\nini_modules.f90' \
 '\ninput_acraneb2.f90' \
 '\noutput_basic.f90' \
 '\ndmi_omp.f90' \
 '\ndmi_timer.f90' > AutoRPE/AdditionalFiles/list_of_files_to_keep_unmodified.txt


# Check python is loaded
python3 -V  >/dev/null 2>&1  ||  { echo "load python3 and try again ..."; exit 1 ; }

cd ${RUNDIR}/AutoRPE

# Run the implementation
python3 ImplementRPEtoSource.py #2> implementation.log

ls ${AutoRPE_Output}

mkdir  ${RUNDIR}/../Remote/ProcessedOutputs

sed -i "s/ call domp_init(nthreads)/ call domp_init(nthreads)\n CALL read_variable_precisions/g" ${AutoRPE_Output}/main.f90 

#Copy procecced files
cp ${AutoRPE_Output}/* ${RUNDIR}/../Remote/ProcessedOutputs
cp -r ${DWARF} ${RUNDIR}/../Remote

# Generate namelist_precisions
python3 NamelistPrecisionsGenerator.py

# Modify original namelist
python3 AdaptNamelists.py
cp ${NEW_NAMELIST}/* ${RUNDIR}/../Remote/Files

# Move everything needed
mv namelist_precisions vault.pkl ${RUNDIR}/../Remote/Files

#coping files to remote
scp -r ${RUNDIR//Local}/Remote mn1.bsc.es:${REMOTE_DIR}
